<template>
  <div>
    <ttable
      :table="table"
      @handleSelectionChange="handleSelectionChange"
      :uploadInfo="uploadInfo"
      :prelang="prelang"
      :options="options"
      :bottomOffset="255"
      :ajaxFun="ajaxFun"
      ref="receivingDetailTable"
      :paramObj="paramObj"
    >
      <template #toolbar></template>
    </ttable>
    <!-- 弹窗, 新增 / 修改 -->
    <table-form
      v-if="addOrUpdateVisible"
      ref="addOrUpdate"
      @refreshDataList="refreshDataList"
    ></table-form>
  </div>
</template>

<script>
import {
  fetchListReceivingDetail,
  delReceivingDetail
} from '@/api/warehouse/receiving'
import { loadLocation } from '@/api/warehouse/location'
import TableForm from './receiving-detail-form'
import { mapGetters } from 'vuex'
import ttable from '@/views/common/ztt-table.vue'

export default {
  props: {
    paramObj: {
      type: Object,
      default: () => {
        return {}
      }
    },
    disabled: {
      type: Boolean,
      default: false
    },
    visible: {
      type: Boolean,
      default: false
    }
  },
  data() {
    return {
      ajaxFun: fetchListReceivingDetail,
      locations: [],
      // 送货清单
      multipleSelection: [],
      isShowQuery: false,
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      prelang: 'operation',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: true, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'receiptTime', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          {
            minWidth: '110',
            prop: 'partNo',
            label: '零件编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text',
            render: { fun: this.addOrUpdateHandle }
          },
          {
            minWidth: '110',
            prop: 'partName',
            label: '零件名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '110',
            prop: 'materialType',
            label: '零件类型',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '100',
            prop: 'locationId',
            label: '库位号',
            sort: true,
            isTrue: true,
            formatter: this.formatLocation,
            isSearch: true,
            searchInfoType: 'select',
            optList: () => {
              return this.locations
            }
          },
          {
            minWidth: '100',
            prop: 'partBatchNo',
            label: '零件批号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '80',
            prop: 'receiveQty',
            label: '接收数量',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '140',
            prop: 'receiptTime',
            label: '接收时间',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'datetimerange'
          },
          {
            minWidth: '80',
            prop: 'unit',
            label: '零件单位',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          }
        ],
        toolbar: null,
        operator: null,
        operatorConfig: {
          fixed: 'right',
          label: '操作',
          width: 120,
          minWidth: 120
        }
      },
      addOrUpdateVisible: false
    }
  },
  components: {
    TableForm,
    ttable
  },
  watch: {
    visible: {
      handler(newValue, oldValue) {
        if (newValue) {
          this.getData()
        }
      },
      immediate: true
    },
    disabled: {
      handler(newValue, oldValue) {
        if (newValue) {
          this.table.operator = null
          this.table.toolbar = null
        } else {
          this.table.operator = [
            {
              text: '修改',
              icon: 'el-icon-edit',
              type: 'text',
              size: 'small',
              fun: this.addOrUpdateHandle
            },
            {
              text: '删除',
              icon: 'el-icon-delete',
              type: 'text',
              size: 'small',
              fun: this.deleteHandle
            }
          ]
          this.table.toolbar = [
            {
              text: '新增',
              icon: 'el-icon-plus',
              type: 'primary',
              fun: this.addOrUpdateHandle
            }
          ]
        }
      },
      immediate: true
    }
  },
  created() {
    this.initLocations()
  },
  computed: {
    ...mapGetters(['permissions'])
  },
  methods: {
    // 获取库位
    initLocations() {
      loadLocation().then((res) => {
        this.locations = JSON.parse(
          JSON.stringify(res.data.data)
            .replace(/id/g, 'value')
            .replace(/locNo/g, 'label')
        )
      })
    },
    // 刷新收料明细列表以及送货清单列表
    refreshDataList() {
      this.getData()
      this.$emit('refreshDataList')
    },
    // 获取数据列表
    getData() {
      if (this.$refs.receivingDetailTable != undefined) {
        this.$refs.receivingDetailTable.getDataList()
      }
    },
    // 新增 / 修改
    addOrUpdateHandle(row) {
      if (!this.paramObj.receivingMainId) {
        this.$message.error('请先保存')
        return
      }
      this.addOrUpdateVisible = true
      this.$nextTick(() => {
        this.$refs.addOrUpdate.init(
          row ? row.id : row,
          this.paramObj.receivingMainId,
          this.paramObj.factoryId
        )
      })
    },
    // 删除
    deleteHandle(row) {
      this.$confirm('是否确认删除', '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        closeOnClickModal: false,
        type: 'warning'
      })
        .then(function() {
          return delReceivingDetail(row ? row.id : row)
        })
        .then((data) => {
          this.$message.success('删除成功')
          this.refreshDataList()
        })
    },
    // table自带事件
    handleSelectionChange(val) {
      this.multipleSelection = val
    },
    // 表格字段格式化
    formatLocation(row, column, cellValue) {
      for (let i = 0, len = this.locations.length; i < len; i++) {
        if (cellValue == this.locations[i].value) {
          return this.locations[i].label
        }
      }
    }
  }
}
</script>
